@@ -37,7 +37,7 @@ class Conv2d(nn.Conv2d):
         self.weight_bit_width = weight_bit_width
         self.bias_bit_width = bias_bit_width
         self.input_bit_width = input_bit_width
-        self.output_bit_width = self.output_bit_width
+        self.output_bit_width = output_bit_width
         self.iostrict = iostrict
 
     def conv_forward(self, input):
